@@ -18,6 +18,7 @@ from typing import Union
 from uuid import UUID
 from uuid import uuid4
 
+from pydantic import BaseModel
 from pydantic import Field
 from pydantic import root_validator
 from pydantic import validator
@@ -63,6 +64,16 @@ class LoraBase(RABase):
     def set_uuid(cls, _uuid: Optional[UUID]) -> UUID:
         return _uuid or uuid4()
 
+    @validator("object_type", pre=True, check_fields=False)
+    def lower_object_type(cls, object_type: Optional[Any]) -> Any:
+        """
+        Lower the object_type before validating equality with the literal, as some LoRa
+        databases define the capitalised value, while others do not.
+        """
+        if isinstance(object_type, str):
+            return object_type.lower()
+        return object_type
+
 
 # --------------------------------------------------------------------------------------
 # Infinite Datetime
@@ -180,9 +191,15 @@ class EffectiveTime(RABase):
     from_date: InfiniteDatetime = Field(
         alias="from", description="Start of the effective time interval."
     )
+    from_included: Optional[bool] = Field(
+        description="Whether from_date is included in the interval."
+    )
     to_date: InfiniteDatetime = Field(
         alias="to", description="End of the effective time interval."
     )
+    to_included: Optional[bool] = Field(
+        description="Whether to_date is included in the interval."
+    )
 
     @root_validator
     def check_from_lt_to(cls, values: Dict[str, Any]) -> Dict[str, Any]:
@@ -287,7 +304,7 @@ def get_relations(
     return [Relation(uuid=uuids, effective_time=effective_time)]
 
 
-class Responsible(RABase):
+class Responsible(LoraBase):
     """
     Responsible object in LoRa.
     """
@@ -301,7 +318,35 @@ class Responsible(RABase):
     )
 
 
-class FacetRef(RABase):
+class ClassRef(LoraBase):
+    """
+    Reference to given LoRa class.
+    """
+
+    object_type: Literal["klasse"] = Field(
+        "klasse", alias="objekttype", description="Object type."
+    )
+    uuid: UUID = Field(description="UUID of the reference.")
+    effective_time: EffectiveTime = Field(
+        alias="virkning", description="Effective time of the reference."
+    )
+
+
+class ParentClassification(LoraBase):
+    """
+    ParentClassification object in LoRa.
+    """
+
+    object_type: Literal["klassifikation"] = Field(
+        "klassifikation", alias="objekttype", description="Object type."
+    )
+    uuid: UUID = Field(description="UUID of the object.")
+    effective_time: EffectiveTime = Field(
+        alias="virkning", description="Effective time of the object."
+    )
+
+
+class FacetRef(LoraBase):
     """
     Reference to given LoRa facets.
     """
@@ -326,6 +371,12 @@ class FacetRelations(RABase):
         max_items=1,
         description="The responsible object.",
     )
+    parent: Optional[List[ParentClassification]] = Field(
+        alias="facettilhoerer",
+        min_items=1,
+        max_items=1,
+        description="The parent classification.",
+    )
 
 
 class ITSystemProperties(RABase):
@@ -477,6 +528,12 @@ class KlasseRelations(RABase):
     facet: List[FacetRef] = Field(
         min_items=1, max_items=1, description="Facet reference."
     )
+    parent: Optional[List[ClassRef]] = Field(
+        alias="overordnetklasse",
+        min_items=1,
+        max_items=1,
+        description="The parent class object.",
+    )
 
 
 class KlasseAttributes(RABase):
@@ -571,3 +628,12 @@ class OrganisationRelations(RABase):
         max_items=1,
         description="Authority object denoting the relations.",
     )
+
+
+class RegistrationTime(BaseModel):
+    timestamp_datetime: InfiniteDatetime = Field(
+        alias="tidsstempeldatotid", description="The registration timestamp"
+    )
+    limit_indicator: Optional[bool] = Field(
+        alias="graenseindikator", description="The registration limit indicator"
+    )
