@@ -15,6 +15,7 @@ from pydantic import Field
 
 from .._shared import AssociationType
 from .._shared import DynamicClasses
+from .._shared import EmployeeRef
 from .._shared import MOBase
 from .._shared import OrgUnitRef
 from .._shared import PersonRef
@@ -39,16 +40,18 @@ class AssociationBase(MOBase):
 class AssociationRead(AssociationBase):
     """A MO AssociationRead object."""
 
-    org_unit: UUID = Field(
+    org_unit_uuid: UUID = Field(
         description="UUID of the organisation unit related to the association."
     )
-    person: UUID = Field(description="UUID of the person related to the association.")
-    association_type: UUID = Field(description="UUID of the association type.")
-    primary: Optional[UUID] = Field(
+    employee_uuid: UUID = Field(
+        description="UUID of the employee related to the association."
+    )
+    association_type_uuid: UUID = Field(description="UUID of the association type.")
+    primary_uuid: Optional[UUID] = Field(
         description="UUID of the primary type of the association."
     )
-    substitute: Optional[UUID] = Field(
-        description="UUID of the substitute for the person in the association."
+    substitute_uuid: Optional[UUID] = Field(
+        description="UUID of the substitute for the employee in the association."
     )
 
 
@@ -58,20 +61,23 @@ class AssociationWrite(AssociationBase):
     org_unit: OrgUnitRef = Field(
         description="Reference to the organisation unit for the association."
     )
-    person: PersonRef = Field(
-        description="Reference to the person for which the engagement should be "
-        "created."
+    employee: EmployeeRef = Field(
+        description=(
+            "Reference to the employee for which the engagement should be created."
+        )
     )
     association_type: AssociationType = Field(
         description="Reference to the association type klasse."
     )
     primary: Optional[Primary] = Field(
-        description="Reference to the primary klasse for the created association "
-        "object."
+        description=(
+            "Reference to the primary klasse for the created association object."
+        )
     )
-    substitute: Optional[PersonRef] = Field(
-        description="Reference to the substitute for the person in the association "
-        "object."
+    substitute: Optional[EmployeeRef] = Field(
+        description=(
+            "Reference to the substitute for the employee in the association object."
+        )
     )
 
 
@@ -84,12 +90,15 @@ class Association(MOBase):
         "association", alias="type", description="The object type."
     )
     org_unit: OrgUnitRef = Field(
-        description="Reference to the organisation unit "
-        "for which the association should be created."
+        description=(
+            "Reference to the organisation unit for which the association should be "
+            "created."
+        )
     )
     person: PersonRef = Field(
-        description="Reference to the person "
-        "for which the association should be created."
+        description=(
+            "Reference to the person for which the association should be created."
+        )
     )
     association_type: AssociationType = Field(
         description="Reference to the association type facet."
@@ -101,12 +110,12 @@ class Association(MOBase):
     @classmethod
     def from_simplified_fields(
         cls,
-        uuid: UUID,
         org_unit_uuid: UUID,
         person_uuid: UUID,
         association_type_uuid: UUID,
         from_date: str,
         to_date: Optional[str] = None,
+        uuid: Optional[UUID] = None,
     ) -> "Association":
         """Create a new association from simplified fields."""
         validity = Validity(from_date=from_date, to_date=to_date)
