@@ -30,12 +30,14 @@ class RelatedUnitBase(MOBase):
 class RelatedUnitRead(RelatedUnitBase):
     """A MO RelatedUnitRead object."""
 
-    org_unit: List[UUID] = Field(description="UUIDs of the related organisation units.")
+    org_unit_uuids: List[UUID] = Field(
+        description="UUIDs of the related organisation units."
+    )
 
 
 class RelatedUnitWrite(RelatedUnitBase):
     """A MO RelatedUnitWrite object."""
 
-    org_unit: List[OrgUnitRef] = Field(
+    org_units: List[OrgUnitRef] = Field(
         description="List of references of the related the organisation units."
     )
